package com.yutou.nas.mybatis.dao;

import com.yutou.nas.mybatis.model.BangumiList;
import com.yutou.nas.mybatis.model.BangumiListExample;
import java.util.List;

import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
@Mapper
public interface BangumiListDao {
    long countByExample(BangumiListExample example);

    int deleteByExample(BangumiListExample example);

    int deleteByPrimaryKey(Integer id);

    int insert(BangumiList record);

    int insertSelective(BangumiList record);

    List<BangumiList> selectByExample(BangumiListExample example);

    BangumiList selectByPrimaryKey(Integer id);

    int updateByExampleSelective(@Param("record") BangumiList record, @Param("example") BangumiListExample example);

    int updateByExample(@Param("record") BangumiList record, @Param("example") BangumiListExample example);

    int updateByPrimaryKeySelective(BangumiList record);

    int updateByPrimaryKey(BangumiList record);
}